package game

import (
	"fmt"
	"sirlab.de/go/knyt/syncdata"
)

func (gm *Game) populateSyncDataCb(syncData *syncdata.SyncData) {
	syncData.GameInfo = gm.populateGameInfo()
}

func (gm *Game) populateGameInfo() syncdata.GameInfo {
	gm.mu.Lock()
	defer gm.mu.Unlock()

	return syncdata.GameInfo{
		GameId:  gm.id,
		State:   gm.state,
		Phase:   gm.phase,
		Players: gm.getPlayers(),
		Round:   gm.getRoundInfo(),
	}
}

func (gm *Game) getPlayers() []syncdata.PlayerInfo {
	players := make([]syncdata.PlayerInfo, 0)
	for _, p := range gm.players {
		if p.isPlaying {
			players = append(players, syncdata.PlayerInfo{
				Id:     p.id,
				Name:   p.name,
				IsIdle: p.isIdle,
			})
		}
	}

	return players
}

func (gm *Game) getRoundInfo() *syncdata.RoundInfo {
	if gm.state != STATE_PLAY {
		return nil
	}

	quote := gm.quotes[gm.round.quoteId]
	if quote == nil {
		fmt.Printf("fatal error: quote id \"%s\" not found\n", gm.round.quoteId)
		return nil
	}

	roundInfo := syncdata.RoundInfo{
		Quote:   quote.GetQuote(),
		Sources: gm.round.sources,
	}

	return &roundInfo
}
